@@ -11,16 +11,15 @@ def deserialize_df(buf):
     return context.deserialize(buf)
 
 
-def serialize_pq(pq):
+def serialize_pa_table(pa_table):
     sink = pa.BufferOutputStream()
-    writer = pa.ipc.new_stream(sink, pq.schema)
-    writer.write(pq)
-    writer.close()
+    with pa.ipc.RecordBatchStreamWriter(sink, pa_table.schema) as writer:
+        writer.write(pa_table)
     buf = sink.getvalue()
     return buf
 
 
-def deserialize_pq(buf):
+def deserialize_pa_table(buf):
     reader = pa.ipc.open_stream(buf)
-    pq = reader.read_all()
-    return pq
+    pa_table = reader.read_all()
+    return pa_table
